AppUpdateInfo class

AppUpdateInfo

Constructors

AppUpdateInfo({String? packageName, UpdateAvailability? updateAvailability, bool? immediateAllowed, bool? flexibleAllowed, num? clientVersionStalenessDays, int? updatePriority, int? availableVersionCode, int? installStatus})
Contructs an instance
AppUpdateInfo.fromJson(Map? json)
An instance of the AppUpdateInfo from json

Properties

availableVersionCode ↔ int
getter/setter pair
clientVersionStalenessDays ↔ num
getter/setter pair
flexibleAllowed ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
immediateAllowed ↔ bool
getter/setter pair
installStatus ↔ int
getter/setter pair
packageName ↔ String
Getter & setter
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateAvailability ↔ UpdateAvailability
getter/setter pair
updatePriority ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a JSON object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited