VersionInfo class

VersionInfo

Constructors

VersionInfo({String? localVersion, String? storeVersion, String? appStoreLink, String? releaseNotes, String? releaseDate})
An instance of the VersionInfo Constructor

Properties

getter/setter pair
canUpdate → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
isReviewing → bool?
no setter
localVersion ↔ String
Getter & Setter
getter/setter pair
releaseDate → DateTime?
no setter
releaseNotes ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storeVersion ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a JSON object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited