InAppUpdatePlatform class abstract

The interface that implementations of in-app-update must implement

Support Android The in-app updates feature is supported on devices running Android 5.0 (API level 21) or higher. Additionally, in-app updates are only supported for Android mobile devices, Android tablets, and Chrome OS devices.

Implementers

Constructors

InAppUpdatePlatform()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkForUpdate() → Future<AppUpdateInfo?>
Check for update availability Before requesting an update, check if there is an update available for your app. Using AppUpdateManager to check for update
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startAnUpdate({AppUpdateType type = AppUpdateType.flexible}) → Future<String?>
After you confirm that an update is available, you can request an update Android support: Flexible updates and Immediate updates
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited